@@ -1,12 +1,12 @@
 from urllib import request
 import requests
-import settings
+from  tarifafedextest.settings import URL_API_FEDEX
 import xml.etree.ElementTree as ET
 class ApiService:
 
     def post(self,data):
 
         headers = {'Content-Type': 'application/xml'}
-        return requests.post(settings.URL_API_FEDEX,data = ET.tostring(data),headers = headers) 
+        return requests.post(URL_API_FEDEX,data = ET.tostring(data),headers = headers) 
         
         
\ No newline at end of file
